<?php
function _addUser(&$tof,$vars) {
	require_once("actions/user.php");
	addUser(
		$tof,
		array('Username' => $vars['Username'],
			  'Password' => $vars['Password'],
			  'Name' => $vars['Name'],
			  'Email' => $vars['Email'],
			  'Admin' => $vars['IsAdmin'],
			  'Upload' => $vars['AllowUpload']),
		$vars['NotifyUser']);
}
?>